@@ -3,7 +3,7 @@ BEGIN {
   $Web::Machine::FSM::States::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Web::Machine::FSM::States::VERSION = '0.11';
+  $Web::Machine::FSM::States::VERSION = '0.12';
 }
 # ABSTRACT: The States for Web Machine
 
@@ -747,7 +747,7 @@ Web::Machine::FSM::States - The States for Web Machine
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -778,6 +778,10 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
+Andreas Marienborg <andreas.marienborg@gmail.com>
+
+=item *
+
 Andrew Nelson <anelson@cpan.org>
 
 =item *
@@ -804,6 +808,10 @@ John SJ Anderson <genehack@genehack.org>
 
 Olaf Alders <olaf@wundersolutions.com>
 
+=item *
+
+Thomas Sibley <tsibley@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
