@@ -3,7 +3,7 @@ BEGIN {
   $Web::Machine::I18N::en::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Web::Machine::I18N::en::VERSION = '0.11';
+  $Web::Machine::I18N::en::VERSION = '0.12';
 }
 # ABSTRACT: The English support for I18Ned HTTP information
 
@@ -68,7 +68,7 @@ Web::Machine::I18N::en - The English support for I18Ned HTTP information
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -90,6 +90,10 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
+Andreas Marienborg <andreas.marienborg@gmail.com>
+
+=item *
+
 Andrew Nelson <anelson@cpan.org>
 
 =item *
@@ -116,6 +120,10 @@ John SJ Anderson <genehack@genehack.org>
 
 Olaf Alders <olaf@wundersolutions.com>
 
+=item *
+
+Thomas Sibley <tsibley@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
