@@ -3,7 +3,7 @@ BEGIN {
   $Web::Machine::Resource::AUTHORITY = 'cpan:STEVAN';
 }
 {
-  $Web::Machine::Resource::VERSION = '0.11';
+  $Web::Machine::Resource::VERSION = '0.12';
 }
 # ABSTRACT: A base resource class
 
@@ -90,7 +90,7 @@ Web::Machine::Resource - A base resource class
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -518,6 +518,10 @@ Stevan Little <stevan.little@iinteractive.com>
 
 =item *
 
+Andreas Marienborg <andreas.marienborg@gmail.com>
+
+=item *
+
 Andrew Nelson <anelson@cpan.org>
 
 =item *
@@ -544,6 +548,10 @@ John SJ Anderson <genehack@genehack.org>
 
 Olaf Alders <olaf@wundersolutions.com>
 
+=item *
+
+Thomas Sibley <tsibley@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
